@@ -40,7 +40,7 @@ class CollisionChecker:
 
     def check(self, drone_commands: List[AbstractDroneCommand],
               state_updater_map: Dict[str, StateUpdater],
-              save_check_log: bool = False):
+              save_report: bool = False):
         if len(self.drone_config_map) == 1:
             # no need to check if there is only 1 drone
             return
@@ -55,8 +55,8 @@ class CollisionChecker:
                                    "please retry with a better collision_config. Error: " + str(e))
 
         collisions, time_slice_info = self._get_possible_collisions_and_time_slice_info(drone_trajectory_map)
-        if save_check_log:
-            CollisionLogSaver.save_check_log(time_slice_info)
+        if save_report:
+            CollisionReportSaver.save_check_report(time_slice_info)
         self._check_collisions(collisions)
 
     def _get_possible_collisions_and_time_slice_info(self, drone_trajectory_map: Dict[str, List[StateVariance]]) \
@@ -105,7 +105,7 @@ class CollisionChecker:
                         nc = x ** 2 / variance + y ** 2 / variance + z ** 2 / variance
                         confidence = ncx2.cdf(collision_meters ** 2 / variance, df=3, nc=nc)
 
-                    if confidence >= self.collision_config.confidence_threshold - 1e-5:
+                    if confidence >= self.collision_config.confidence_threshold - 1e-8:
                         collisions.append((name1, name2, state1, state2, mean_distance, confidence))
 
                     time_slice_info.append((name1, name2, time, mean_distance, confidence))
@@ -120,10 +120,9 @@ class CollisionChecker:
                 y = round((state1.y_meters + state2.y_meters) / 2, 2)
                 z = round((state1.z_meters + state2.z_meters) / 2, 2)
                 mean_distance = round(mean_distance, 5)
-                confidence = round(confidence, 5) * 100
                 error_msg += ("Collision might happen between {} and {}, at time {}s, ".format(name1, name2, time) +
-                              "near position (x={}m, y={}m, z={}m), distance={}m, confidence={}%\n"
-                              .format(x, y, z, mean_distance, confidence))
+                              "near position (x={}m, y={}m, z={}m), distance={}m, confidence={:.3f}%\n"
+                              .format(x, y, z, mean_distance, confidence * 100))
             raise SafetyCheckError(error_msg)
 
     def _update_states_for_abstract_drone_command(self, drone_commands: List[AbstractDroneCommand],
@@ -316,19 +315,20 @@ class CollisionChecker:
         return longest_time_used
 
 
-class CollisionLogSaver:
+class CollisionReportSaver:
     @staticmethod
-    def save_check_log(time_slice_info: List[Tuple[str, str, float, float, float]]):
-        log_dir = "logs"
-        if not os.path.isdir(log_dir):
-            os.mkdir(log_dir)
+    def save_check_report(time_slice_info: List[Tuple[str, str, float, float, float]]):
+        report_dir = "reports"
+        if not os.path.isdir(report_dir):
+            os.mkdir(report_dir)
 
-        file_name = os.path.join(log_dir, "collision check log (all drones).txt")
+        file_name = os.path.join(report_dir, "collision check log (all drones).txt")
 
         with open(file_name, "w") as file:
             sorted_time_slice_info = sorted(time_slice_info, key=lambda elem: elem[2])
-            file.write(tabulate(sorted_time_slice_info,
-                                headers=["Drone 1", "Drone 2", "Time", "Distance", "Confidence"]))
+            file.write(tabulate(CollisionReportSaver._format_rows(sorted_time_slice_info),
+                                headers=["Drone 1", "Drone 2", "Time", "Distance", "Confidence"],
+                                colalign=("default", "default", "default", "default", "right")))
 
         drone_pairs = sorted(set([(name1, name2) for (name1, name2, _, _, _) in time_slice_info]))
 
@@ -336,10 +336,11 @@ class CollisionLogSaver:
             filtered_time_slice_info = filter(lambda elem: drone_pair == (elem[0], elem[1]), time_slice_info)
             filtered_time_slice_info = sorted(filtered_time_slice_info, key=lambda elem: elem[2])
 
-            file_name = os.path.join(log_dir, "collision check log ({}-{}).txt".format(drone_pair[0], drone_pair[1]))
+            file_name = os.path.join(report_dir, "collision check log ({}-{}).txt".format(drone_pair[0], drone_pair[1]))
             with open(file_name, "w") as file:
-                file.write(tabulate(filtered_time_slice_info,
-                                    headers=["Drone 1", "Drone 2", "Time", "Distance", "Confidence"]))
+                file.write(tabulate(CollisionReportSaver._format_rows(filtered_time_slice_info),
+                                    headers=["Drone 1", "Drone 2", "Time", "Distance", "Confidence"],
+                                    colalign=("default", "default", "default", "default", "right")))
 
             times = [time for (_, _, time, _, _) in filtered_time_slice_info]
             probabilities = [prob for (_, _, _, _, prob) in filtered_time_slice_info]
@@ -349,5 +350,10 @@ class CollisionLogSaver:
             ax.set_ylabel("Probability")
             ax.set_title("Probability of Collision between {} and {}".format(drone_pair[0], drone_pair[1]))
             ax.set_ylim([-0.05, 1.05])
-            fig_name = os.path.join(log_dir, "collision probability ({}-{}).png".format(drone_pair[0], drone_pair[1]))
+            fig_name = os.path.join(report_dir, "collision probability ({}-{}).png".format(drone_pair[0], drone_pair[1]))
             fig.savefig(fig_name)
+
+    @staticmethod
+    def _format_rows(table: List[Tuple[str, str, float, float, float]]) -> List[Tuple[str, str, float, float, str]]:
+        return [(name1, name2, round(time, 3), round(distance, 5), "{:3.3f}%".format(confidence * 100))
+                for (name1, name2, time, distance, confidence) in table]
